@@ -284,8 +284,8 @@ evolution <- function(fn, params, data, s2d, settings, cex) {
         clabel = pd$clabel
     )
     if (pd$transform) args$xlim <- gettimelimits(pd$mint, pd$maxt)
-    else args$xlim <- getlimits(pd$min08, pd$max08)
-    args$ylim <- getlimits(pd$min48, pd$max48)
+    else args$xlim <- getlimits(pd$min08or82, pd$max08or82)
+    args$ylim <- getlimits(pd$min48or02, pd$max48or02)
     graphics::par(cex = cex, mgp = c(2.5,1,0))
     calculate(IsoplotR::evolution, args)
 }
